<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\ORM\ConnectionFactory;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class Operador extends Crud {
	protected $dataSourceName = 'GetOperadoresRepository';

	protected $dataSourceManager;
	protected $operadorService;
	protected $filialService;
	protected $salesMessage;
	protected $util;
	protected $instanceManager;
	protected $SMTPService;

	public function __construct(Manager $dataSourceManager,Services\Operador $operadorService, Services\Filial $filialService, Services\Cliente $clienteService, Services\Consumidor $consumidorService, Services\Produto $produtoService, Services\Fidelidade $fidelityService, Utilities\SalesMessage $salesMessage, Utilities\Util $util, \Zeedhi\Framework\DependencyInjection\InstanceManager $instanceManager,Services\SMTP $SMTPService) {
		$this->operadorService   = $operadorService;
		$this->filialService     = $filialService;
        $this->clienteService    = $clienteService;
        $this->consumidorService = $consumidorService;
        $this->produtoService    = $produtoService;
        $this->fidelityService   = $fidelityService;
		$this->salesMessage      = $salesMessage;
		$this->util              = $util;
		$this->instanceManager   = $instanceManager;
		$this->SMTPService       = $SMTPService;

		parent::__construct($dataSourceManager);
	}

	public function loginOperador(DTO\Request\Filter $request, DTO\Response $response) {
        try {

        	$params = $request->getFilterCriteria()->getConditions();

        	// recebe parâmetros do frontend
        	$DSEMAILOPER      = $params[0]['value'];
        	$CDSENHAOPERMD5   = $params[1]['value'];
        	$demo             = $params[2]['value'];
        	$frontVersion     = $params[3]['value'];

            //transforma em minusculo todos os caracters doe-mail digitados
            $DSEMAILOPER = strtolower($DSEMAILOPER);

            //CRIPTOGRAFA A SENHA
            $CDSENHAOPERMD5 = $this->util->encrypt($CDSENHAOPERMD5);

        	// valida se a versão do frontend está igual à versão do backend
        	$versionResponse = $this->util->checkVersion($frontVersion);

			if (!$versionResponse['versionOk']) {
                // versão não está igual
                throw new \Exception($this->salesMessage->getMessage(1) . $versionResponse['frontVersion'] . $this->salesMessage->getMessage(2) . $versionResponse['backVersion']);
            }

			$doLogin = false;

            $DADOSOPERADOR = $this->operadorService->getOperadorEmail($DSEMAILOPER);
            if(empty($DADOSOPERADOR)){
                $response->addMessage(new Message($this->salesMessage->getMessage(64)));
            } else {

                if(!empty($DADOSOPERADOR) && $DADOSOPERADOR[0]['CDSENHAOPERMD5'] == NULL){
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperadorLoginRepo', array(array('CDSENHAOPERMD5PENDENTE' => true))));
                }else{
                    /* Pego todas as filiais e uso a primeira como default */
                    $filiais = $this->getFilial($DADOSOPERADOR[0]['CDOPERADOR']);
     				$perfis  = $this->operadorService->getPerfilAssociado($DADOSOPERADOR[0]['CDOPERADOR']);
     				if (count($filiais) == 0) {
                        throw new \Exception($this->salesMessage->getMessage(44));
                    }
                    $CDFILIAL = $filiais[0]['CDFILIAL'];

                    /* Pego todas as lojas daquela filial e uso a primeira como default */
                    $lojas  = $this->getLojasByFilialAndOperador($CDFILIAL, $DADOSOPERADOR[0]['CDOPERADOR']);

                    $CDLOJA          = null;
                    $LABELLOJA       = null;
                    $CDALMOXARIFE    = null;
                    $DSALMOXARIFE    = null;
                    $LABELALMOXARIFE = null;
                    $CDLOCALESTOQ    = null;

                    $CDCAIXA         = null;
                    $LABELCAIXA      = null;
                    $NRCONFTELA      = null;

                    if (count($lojas) > 0) {

                        $CDLOJA          = $lojas[0]['CDLOJA'];
                        $LABELLOJA       = $lojas[0]['LABELLOJA'];
                        $CDALMOXARIFE    = $lojas[0]['CDALMOXARIFE'];
                        $DSALMOXARIFE    = $lojas[0]['DSALMOXARIFE'];
                        $LABELALMOXARIFE = $lojas[0]['LABELALMOXARIFE'];
                        $CDLOCALESTOQ    = $lojas[0]['CDLOCALESTOQ'];

                        /* Pego todos os caixas associados à filial e loja default e uso o primeiro */
                        $caixas = $this->getCaixasByFilialAndLoja($CDFILIAL, $lojas[0]['CDLOJA']);
                        if (count($caixas) > 0) {
                            $CDCAIXA    = $caixas[0]['CDCAIXA'];
                            $LABELCAIXA = $caixas[0]['LABELCAIXA'];
                            $NRCONFTELA = $caixas[0]['NRCONFTELA'];
                        }
                    }

                    $respostaDadosPreenchidos = $this->validaDadosPreenchidosLogin($CDFILIAL, $DSEMAILOPER, $CDSENHAOPERMD5);
                    if ($respostaDadosPreenchidos['Ok']) { // dados preenchidos

                        $dadosLogin = array(
                            'DSEMAILOPER'     => $DSEMAILOPER,
                            'CDSENHAOPERMD5'  => $CDSENHAOPERMD5,
                            'FILIAIS'         => $filiais,
                            'CDFILIAL'        => $CDFILIAL,
                            'LABELFILIAL'     => $filiais[0]['LABELFILIAL'],
                            'CDLOJA'          => $CDLOJA,
                            'LABELLOJA'       => $LABELLOJA,
                            'CDALMOXARIFE'    => $CDALMOXARIFE,
                            'DSALMOXARIFE'    => $DSALMOXARIFE,
                            'LABELALMOXARIFE' => $LABELALMOXARIFE,
                            'CDLOCALESTOQ'    => $CDLOCALESTOQ,
                            'CDCAIXA'         => $CDCAIXA,
                            'LABELCAIXA'      => $LABELCAIXA,
                            'NRCONFTELA'      => $NRCONFTELA,
                            'GROUP_ID'		  => $perfis
                        );
                        $this->operadorService->updateHashAlteraSenha($DADOSOPERADOR[0]['CDOPERADOR'], null);
                        $doLogin = true;
                    } else { // dados não preenchidos
                        $response->addMessage(new Message($respostaDadosPreenchidos['message']));
                        $doLogin = false;
                    }
                }

            	if ($doLogin) {
            		$respostaLogin = $this->validaLogin($dadosLogin);

            		if ($respostaLogin['loginOk']) {

            			// login realizado com sucesso
            			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperadorLoginRepo', $respostaLogin['dadosOperador']));

            		} else {
            			$response->addMessage(new Message($respostaLogin['message']));
            		}
            	}
            }
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function autoLoginOperador(DTO\Request\Filter $request, DTO\Response $response) {
        try {

        	$params = $request->getFilterCriteria()->getConditions();

        	// recebe parâmetros do frontend
        	$DSEMAILOPER      = $params[0]['value'];
        	$CDSENHAOPERMD5   = $params[1]['value'];
        	$frontVersion     = $params[2]['value'];



            //transforma em minusculo todos os caracters doe-mail digitados
            $DSEMAILOPER = strtolower($DSEMAILOPER);

        	// valida se a versão do frontend está igual à versão do backend
        	$versionResponse = $this->util->checkVersion($frontVersion);

			if (!$versionResponse['versionOk']) {
                // versão não está igual
                throw new \Exception($this->salesMessage->getMessage(1) . $versionResponse['frontVersion'] . $this->salesMessage->getMessage(2) . $versionResponse['backVersion']);
            }

			$doLogin = false;

            $DADOSOPERADOR = $this->operadorService->getOperadorEmail($DSEMAILOPER);


            if(empty($DADOSOPERADOR)){

 				$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperadorLoginRepo', array('doLogin' => $doLogin)));

            } else {

                    /* Pego todas as filiais e uso a primeira como default */
                    $filiais = $this->getFilial($DADOSOPERADOR[0]['CDOPERADOR']);
                    $perfis = $this->operadorService->getPerfilAssociado($DADOSOPERADOR[0]['CDOPERADOR']);

                    if (count($filiais) == 0) {
                        throw new \Exception($this->salesMessage->getMessage(44));
                    }
                    $CDFILIAL = $filiais[0]['CDFILIAL'];

                    /* Pego todas as lojas daquela filial e uso a primeira como default */
                    $lojas  = $this->getLojasByFilialAndOperador($CDFILIAL, $DADOSOPERADOR[0]['CDOPERADOR']);

                    $CDLOJA          = null;
                    $LABELLOJA       = null;
                    $CDALMOXARIFE    = null;
                    $DSALMOXARIFE    = null;
                    $LABELALMOXARIFE = null;
                    $CDLOCALESTOQ    = null;

                    $CDCAIXA         = null;
                    $LABELCAIXA      = null;
                    $NRCONFTELA      = null;

                    if (count($lojas) > 0) {

                        $CDLOJA          = $lojas[0]['CDLOJA'];
                        $LABELLOJA       = $lojas[0]['LABELLOJA'];
                        $CDALMOXARIFE    = $lojas[0]['CDALMOXARIFE'];
                        $DSALMOXARIFE    = $lojas[0]['DSALMOXARIFE'];
                        $LABELALMOXARIFE = $lojas[0]['LABELALMOXARIFE'];
                        $CDLOCALESTOQ    = $lojas[0]['CDLOCALESTOQ'];

                        /* Pego todos os caixas associados à filial e loja default e uso o primeiro */
                        $caixas = $this->getCaixasByFilialAndLoja($CDFILIAL, $lojas[0]['CDLOJA']);
                        if (count($caixas) > 0) {
                            $CDCAIXA    = $caixas[0]['CDCAIXA'];
                            $LABELCAIXA = $caixas[0]['LABELCAIXA'];
                            $NRCONFTELA = $caixas[0]['NRCONFTELA'];
                        }
                    }

                    $respostaDadosPreenchidos = $this->validaDadosPreenchidosLogin($CDFILIAL, $DADOSOPERADOR[0]['DSEMAILOPER'], $DADOSOPERADOR[0]['CDSENHAOPERMD5']);
                    if ($respostaDadosPreenchidos['Ok']) { // dados preenchidos

                        $dadosLogin = array(
                            'DSEMAILOPER'     => $DADOSOPERADOR[0]['DSEMAILOPER'],
                            'CDSENHAOPERMD5'  => $CDSENHAOPERMD5,
                            'FILIAIS'         => $filiais,
                            'CDFILIAL'        => $CDFILIAL,
                            'LABELFILIAL'     => $filiais[0]['LABELFILIAL'],
                            'CDLOJA'          => $CDLOJA,
                            'LABELLOJA'       => $LABELLOJA,
                            'CDALMOXARIFE'    => $CDALMOXARIFE,
                            'DSALMOXARIFE'    => $DSALMOXARIFE,
                            'LABELALMOXARIFE' => $LABELALMOXARIFE,
                            'CDLOCALESTOQ'    => $CDLOCALESTOQ,
                            'CDCAIXA'         => $CDCAIXA,
                            'LABELCAIXA'      => $LABELCAIXA,
                            'NRCONFTELA'      => $NRCONFTELA,
                            'GROUP_ID'		  => $perfis
                        );
                        $doLogin = true;
                    } else { // dados não preenchidos
                        $doLogin = false;
                        $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperadorLoginRepo', array('doLogin' => $doLogin)));
                    }
                }

            	if ($doLogin) {
            		$respostaLogin = $this->validaLogin($dadosLogin);

            		if ($respostaLogin['loginOk']) {
            			// login realizado com sucesso
            			array_push($respostaLogin['dadosOperador'], $doLogin );
            			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperadorLoginRepo', $respostaLogin['dadosOperador']));
            		} else {
            			$doLogin = false;

            		}
            	}

        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    private function getFilial ($CDOPERADOR) {
        return $this->operadorService->getFilial($CDOPERADOR);
    }

    private function getLojasByFilialAndOperador ($CDFILIAL, $CDOPERADOR) {
        return $this->operadorService->getLojasByFilialAndOperador($CDFILIAL, $CDOPERADOR);
    }

    public function getStores(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();
            $CDFILIAL   = $params[0]['value'];
            $CDOPERADOR = $params[1]['value'];

            $lojas = $this->operadorService->getLojasByFilialAndOperador($CDFILIAL, $CDOPERADOR);
            if(count($lojas)==0){

                $response->addMessage(new Message($this->salesMessage->getMessage(63)));
            }
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperatorStoresRepository', $lojas));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getSalePoints(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

            $CDFILIAL   = $params[0]['value'];
            $CDLOJA     = $params[1]['value'];

            $caixas = $this->operadorService->getCaixaByLojaAndFilial($CDFILIAL, $CDLOJA);

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('OperatorSalePointRepository', $caixas));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    private function getCaixasByFilialAndLoja ($CDFILIAL, $CDLOJA) {
        return $this->operadorService->getCaixaByLojaAndFilial($CDFILIAL, $CDLOJA);
    }

    private function validaLogin($dadosLogin) {
    	$respostaLogin = array(
    		'loginOk' => false
		);
        // valida se filial  existe
    	$filial = $this->filialService->getFilial($dadosLogin['CDFILIAL']);
    	if (sizeof($filial) === 0) {
    		// filial não encontrada
    		$respostaLogin['message'] = $this->salesMessage->getMessage(7);
    	} else {
    		// valida se operador existe para a filial
    		$operador = $this->operadorService->getOperadorByFilial($dadosLogin['DSEMAILOPER'], $dadosLogin['CDFILIAL']);
    		$operador[0]['FILIAIS']         = $dadosLogin['FILIAIS'];
            $operador[0]['CDFILIAL']        = $dadosLogin['CDFILIAL'];
            $operador[0]['LABELFILIAL']     = $dadosLogin['LABELFILIAL'];
            $operador[0]['CDLOJA']          = $dadosLogin['CDLOJA'];
            $operador[0]['LABELLOJA']       = $dadosLogin['LABELLOJA'];
            $operador[0]['CDALMOXARIFE']    = $dadosLogin['CDALMOXARIFE'];
            $operador[0]['LABELALMOXARIFE'] = $dadosLogin['LABELALMOXARIFE'];
            $operador[0]['CDALMOXARIFE']    = $dadosLogin['CDALMOXARIFE'];
            $operador[0]['CDLOCALESTOQ']    = $dadosLogin['CDLOCALESTOQ'];
            $operador[0]['CDCAIXA']         = $dadosLogin['CDCAIXA'];
            $operador[0]['LABELCAIXA']      = $dadosLogin['LABELCAIXA'];
            $operador[0]['NRCONFTELA']      = $dadosLogin['NRCONFTELA'];
            $operador[0]['GROUP_ID']        = $dadosLogin['GROUP_ID'];


            if (sizeof($operador) === 0) {
    			// operador não encontrado
    			$respostaLogin['message'] = $this->salesMessage->getMessage(6);
    		} else {
    			// valida se a senha do operador está correta
    			if ($dadosLogin['CDSENHAOPERMD5'] !== $operador[0]['CDSENHAOPERMD5']) {
    				// senha inválida
    				$respostaLogin['message'] = $this->salesMessage->getMessage(8);
    			} else {
    				$respostaLogin['loginOk'] = true;
    				$respostaLogin['dadosOperador'] = $operador[0];
    			}
    		}
    	}
    	return $respostaLogin;
    }

    private function validaDadosPreenchidosLogin($CDFILIAL, $DSEMAILOPER, $CDSENHAOPERMD5) {
		$response = array(
			'Ok' => false
		);

        if ($CDFILIAL == null) {
            $response['message'] = $this->salesMessage->getMessage(3);
        } else if ($DSEMAILOPER == null) {
            $response['message'] = $this->salesMessage->getMessage(4);
        } else if ($CDSENHAOPERMD5 == null) {
            $response['message'] = $this->salesMessage->getMessage(5);
        } else {
        	$response['Ok'] = true;
        }

        return $response;
    }

    public function carregaDados(DTO\Request\Filter $request, DTO\Response $response){
	/*        $params = $request->getFilterCriteria()->getConditions();

        //$buscaFilial    = $this->filialService->buscaFilial();
        //$buscaProdutos  = $this->produtoService->buscaProdutos();
        //$todasCampanhas = $this->fidelityService->todasCampanhas();
        //$tiposCampanha  = $this->fidelityService->tiposCampanha();
        //$produtosVenda  = $this->produtoService->buscaProdutosCardapioEComposicao($params[0]['value'], $params[1]['value']);
        //$buscaCliente   = $this->clienteService->buscaClientes();
        //$tipoConsumidor = $this->consumidorService->buscaTipoConsumidor();
        //$operadores = $this->operadorService->getOperadores();

        $produtosValues = array();
        for($i = 0; $i < count($buscaProdutos); ++$i) {
            $produtosValues[$i] = array_values($buscaProdutos[$i]);
        }

        $produtoskeys = array_keys($buscaProdutos[0]);

        //$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdutosVenda', $produtosVenda));
	   // $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('GetOperadoresRepository', $operadores));
       // $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('TodasCampanhasRepo', $todasCampanhas));
        //$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('TiposCampanhaRepo', $tiposCampanha));
        //$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('FiliaisRepo', $buscaFilial));
       // $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ProdutosRepo', array('values' => $produtosValues, 'keys' => $produtoskeys)));
       // $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ClientesRepo', $buscaCliente));
        //$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('TipoConsRepo', $tipoConsumidor));
	*/
   }

   public function criptographyPassword(DTO\Request\Filter $request, DTO\Response $response){

          $params = $request->getFilterCriteria()->getConditions();
          $password = $params[0]['value'];

          $connectionFactory = new ConnectionFactory();
          $password = $connectionFactory->encrypt($password);
          $retorno = array();
          $retorno['criptography'] = $password;

          $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('CriptographyPassRepo', array($retorno)));
   }

    public function esqueciMinhaSenha(DTO\Request\Filter $request, DTO\Response $response){
        try {
            $params = $request->getFilterCriteria()->getConditions();

	        $DSEMAILOPER = $params[0]['value'];
	        $baseUrl     = $params[1]['value'];


	        //transforma em minusculo todos os caracters doe-mail digitados
	        $DSEMAILOPER = strtolower($DSEMAILOPER);
	        $DADOSOPERADOR = $this->operadorService->getOperadorEmail($DSEMAILOPER);

	        if (empty($DADOSOPERADOR)) {
	            $response->addMessage(new Message($this->salesMessage->getMessage(16)));
	        } else {
		        $CDOPERADOR = $DADOSOPERADOR[0]['CDOPERADOR'];
		        $hash = $this->buildHashCode($CDOPERADOR);
		        $linkForChange = $this->generateLink($baseUrl, $hash);
	            $NMOPERADOR = $DADOSOPERADOR[0]['NMOPERADOR'];

		        $subject  = $this->salesMessage->getMessage('101');
		        $sender = $this->salesMessage->getMessage('102');
		        $content =
			        '<p>Olá '.$NMOPERADOR. '!</p>'.
					'<p>Acesse o link a seguir para alterar sua senha: <b>'.
					'<a href='.$linkForChange.'>'.'Clique Aqui'.'</a>'.'</b> </p>'
				;

		        $this->SMTPService->sendEmail($NMOPERADOR, $DSEMAILOPER, $sender, $subject, $content);

		        $this->operadorService->updateHashAlteraSenha($CDOPERADOR, $hash);

	            $response->addMessage(new Message($this->salesMessage->getMessage(17)));
        	}
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function updatePassword(DTO\Request\Filter $request, DTO\Response $response){

    	$params = $request->getFilterCriteria()->getConditions();

    	$newPassword = $params[0]['value'];
        $currentPasswordTyped = $params[1]['value'];
        $CDOPERADOR = $params[2]['value'];
        $DSEMAILOPER = $params[3]['value'];

        $currentSavedPassword = $this->operadorService->getSenhaOperEmail($DSEMAILOPER);
        $currentSavedPassword = $currentSavedPassword[0]['CDSENHAOPERMD5'];
        $encryptedCurrentPasswordTyped = $this->util->encrypt($currentPasswordTyped);

        if($currentSavedPassword == $encryptedCurrentPasswordTyped){
        		$newPassword = $this->util->encrypt($newPassword);
        		$this->operadorService->updatePassword($CDOPERADOR, $newPassword);
        		$this->operadorService->updateHashAlteraSenha($CDOPERADOR, null);
        		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('UpdatePasswordRepo', array('mensagem' => 'Senha alterada com sucesso.')));

    	} else {
            $response->addMessage(new Message($this->salesMessage->getMessage(8)));
        }
        
    }

    private function buildHashCode($CDOPERADOR) {
    	$time = microtime(true);
        $hash = $this->util->encrypt($CDOPERADOR.$time.rand(0, 99999999));

        $hashArray = str_split($hash);
        $operatorArray = str_split($CDOPERADOR);

        $parImpar = rand(0, 1);

        $finallyHash = "";
        foreach ($hashArray as $key => $hashValue) {
        	if ($key % 2 == $parImpar && count($operatorArray) > 0) {
        		$finallyHash .= array_shift($operatorArray);
        	} else {
        		$finallyHash .= $hashValue;
        	}
        }
        $finallyHash .= $parImpar;

        return $finallyHash;
    }

    private function getCDOPERADORByHash ($hash, $length) {
    	$hashArray = str_split($hash);

        $parImpar = $hashArray[count($hashArray) -1];

        $CDOPERADOR = "";
        foreach ($hashArray as $key => $hashValue) {
            if ($key % 2 == $parImpar) {
                $CDOPERADOR .= $hashValue;
            }
        }

    	$CDOPERADOR = substr($CDOPERADOR, 0, $length);
    	return $CDOPERADOR;
    }

    private function generateLink ($baseUrl, $hash) {
    	return $baseUrl.'?'.$hash;
    }

    public function defineSenha(DTO\Request\Filter $request, DTO\Response $response){
        $params = $request->getFilterCriteria()->getConditions();

        $CDSENHAOPERMD5 = $params[0]['value'];
        $DSEMAILOPER = $params[1]['value'];

        $CDSENHAOPERMD5 = $this->util->encrypt($CDSENHAOPERMD5);

        $this->operadorService->defineSenha($CDSENHAOPERMD5, $DSEMAILOPER);
        $response->addMessage(new Message($this->salesMessage->getMessage(37)));

    }

	public function loadOperador(DTO\Request\Filter $request, DTO\Response $response){
        try {

            $operador = $this->operadorService->loadOperador();

            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('LoadOperadorRepository', $operador));
        } catch (\Exception $e) {
            $response->addMessage(new Message($e->getMessage()));
        }
    }

    public function getPerfilOper($CDOPERADOR){

    	$perfil = $this->operadorService->getPerfilAssociado($CDOPERADOR);
    	$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('GetPerfilAssociadoRepo', $perfil));
    }

}