<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Controller\CrudWithParameterBag;

class RelVendasProdutoConsAnaliticoOrd extends CrudWithParameterBag {


    const dataSourceConsumidor  = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_Cons',
          dataSourceTipoCons    = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_TipoCons',
          dataSourceLoja        = 'select_loja_by_filial',
          dataSourceCliente     = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_Cliente';
          
    protected $parameterBagColumnsConsumidor = array('CDFILIAL', 'CDTIPOCONS', 'TCDTIPOCONS'),
              $parameterBagColumnsTipoCons   = array(),
              $parameterBagColumnsLoja       = array('NRORG', 'CDFILIAL'),
              $parameterBagColumnsCliente    = array('NRORG', 'CDFILIAL'),
              $parameterBagColumnsProduto    = array('NRORG'),  
              $parameterBagProdGrpSeg        = array('P_CDFILIAL', 'P_CDNVPRODUTO'),
              $parameterBagGeral             = array('NRORG', 'CDFILIAL', 'CDNVPRODUTO'),
              $parameterBagColumnsRel        = array ('TCDCONSUMIDOR', 'CDCONSUMIDOR', 'CDCLIENTE', 'CDPRODUTO', 'CDTIPOCONS', 'TCDCLIENTE',
                                                      'TCDTIPOCONS', 'CDLOJA', 'TCDLOJA', 'DTLANCFIN', 'TCDPRODUTO', 'DTLANCINI', 'CDFILIAL', 'MODALIDADE', 'TMODALIDADE');
              
    public function __construct ($crudService, $parameterBag, $entityManager, Manager $dataSourceManager, $utilService) {
        $this->crudService              = $crudService;
        $this->parameterBag             = $parameterBag;
        $this->entityManager            = $entityManager;
        $this->dataSourceManager        = $dataSourceManager;
        $this->utilService              = $utilService;
    }
    
    public function findRel (DTO\Request\Filter $request, DTO\Response $response) {
        ini_set('memory_limit', '512M');
        set_time_limit(120);
        $dataSourceName       = $this->dataSourceName = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd';
        $conditions           = $this->utilService->getParamsAsArray($request);
        $dataSourceFilter     = RelVendasProdutoConsAnaliticoOrd::prepareParameters($conditions);
        $requestDataSourceFilter = $request->getFilterCriteria()->getConditions();
        foreach($requestDataSourceFilter as $filter) {
            if($filter['operator'] === 'MAPPED_LIKE_ALL') {
                array_push($dataSourceFilter, $filter);
            }
        }
        $newRequest           = new DTO\Request\Filter(
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage(),
                $request->getFilterCriteria()->getPageSize()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagColumnsRel;
        parent::find($newRequest, $response);
    }
    
    public function findConsumidor(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName      = self::dataSourceConsumidor;
        $this->parameterBagColumns = $this->parameterBagColumnsConsumidor;
        $conditions                = $this->utilService->getParamsAsArray($request);
        $dataSourceFilter          = RelVendasProdutoConsAnaliticoOrd::prepareConsParameters($conditions);
        $requestDataSourceFilter = $request->getFilterCriteria()->getConditions();
        foreach($requestDataSourceFilter as $filter) {
            if($filter['operator'] === 'MAPPED_LIKE_ALL') {
                array_push($dataSourceFilter, $filter);
            }
        }
        
        $newRequest           = new DTO\Request\Filter(
            new FilterCriteria(
                $this->dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        
        parent::find($newRequest, $response);
    }
    
    public function findTipoCons(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName      = self::dataSourceTipoCons;
        $this->parameterBagColumns = $this->parameterBagColumnsTipoCons;
        parent::find($request, $response);
    }
    
    public function findLojaByFilial(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName      = self::dataSourceLoja;
        $this->parameterBagColumns = $this->parameterBagColumnsLoja;
        parent::find($request,$response);
    }
    
    public function findCliente(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName      = self::dataSourceCliente;
        $this->parameterBagColumns = $this->parameterBagColumnsCliente;
        parent::find($request,$response);
    }
    
    public function findProduto(DTO\Request\Filter $request, DTO\Response $response){
        $this->parameterBagColumns = $this->parameterBagColumnsProduto;
        $conditions = $this->utilService->getParamsAsArray($request);
        $parameters = array(
            'CDFILIAL'  => $conditions['CDFILIAL'],
            'NRORG'     => $conditions['NRORG']
        );
        $resposta   = $this->entityManager->getConnection()->executeQuery(self::QUERY_PRODUTO, $parameters)->fetchAll();
        $resposta = $resposta[0]; 
        
        if(!empty($resposta)){
            
            //Verifica os parametros de retorno da qry QUERY_PRODUTO e envia para os datasources corretos para buscar os parâmetros
            if(($resposta['CDGRPRODPDV'] != NULL) && ($resposta['CDSEGMER']!= NULL)){
                RelVendasProdutoConsAnaliticoOrd::findProdutoWithGrpAndSeg($conditions, $request, $response);
            } else if(($resposta['CDGRPRODPDV'] != NULL) && ($resposta['CDSEGMER']== NULL)){
                RelVendasProdutoConsAnaliticoOrd::findProdutoWithGrp($conditions, $request, $response);
            } else if(($resposta['CDGRPRODPDV'] == NULL) && ($resposta['CDSEGMER']!= NULL)){
                RelVendasProdutoConsAnaliticoOrd::findProdutoWithSeg($conditions, $request, $response);
            } else if (($resposta['CDGRPRODPDV'] == NULL) && ($resposta['CDSEGMER'] == NULL)){
                RelVendasProdutoConsAnaliticoOrd::findProdutoAlt($conditions, $request, $response);
            }
        } else {
            RelVendasProdutoConsAnaliticoOrd::findProdutoGeral($conditions, $request, $response);
        }
    }
    
    public function findProdutoGeral($conditions, $request, $response){
        $dataSourceName            = $this->dataSourceName = 'vnd03700_selectProduto';
        $dataSourceFilter          = array();
        $dataSourceFilter[0] = array(
            "columnName" => 'NRORG',
            "operator"   => "=",
            "value"      => $conditions['NRORG']
        ); 
        $dataSourceFilter[1] = array(
            "columnName" => 'CDFILIAL',
            "operator"   => "=",
            "value"      => $conditions['CDFILIAL']
        ); 
        $dataSourceFilter[2] = array(
            "columnName" => 'CDNVPRODUTO',
            "operator"   => "=",
            "value"      => $conditions['P_CDNVPRODUTO']
        );
        $array_Conditions = array_keys($conditions);
        for($i = 3; $i < sizeof($array_Conditions); $i++) {
                array_push($dataSourceFilter, array(
                    "columnName" => $array_Conditions[$i],
                    "operator"   => "LIKE_I",
                    "value"      => $conditions[$array_Conditions[$i]]
                ));
        }
        
        $newRequest                = new DTO\Request\Filter(
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagGeral;
        parent::find($newRequest, $response);
    }
    
    public function findProdutoWithGrpAndSeg($conditions, $request, $response){
        $dataSourceName            = $this->dataSourceName = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_Prod';
        $dataSourceFilter          = array();
        $dataSourceFilter[0] = array(
            "columnName" => 'P_CDFILIAL',
            "operator"   => "=",
            "value"      => $conditions['CDFILIAL']
        ); 
        $array_Conditions = array_keys($conditions);
        for($i = 2; $i < sizeof($array_Conditions); $i++) {
                array_push($dataSourceFilter, array(
                    "columnName" => $array_Conditions[$i],
                    "operator"   => "LIKE_I",
                    "value"      => $conditions[$array_Conditions[$i]]
                ));
        }
        $newRequest                = new DTO\Request\Filter(
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagProdGrpSeg;
        parent::find($newRequest, $response);
    }
    
    public function findProdutoWithGrp($conditions, $request, $response){
        $dataSourceName            = $this->dataSourceName = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_ProdGrp';
        $dataSourceFilter          = array();
        $dataSourceFilter[0] = array(
            "columnName" => 'P_CDFILIAL',
            "operator"   => "=",
            "value"      => $conditions['CDFILIAL']
        ); 
        $array_Conditions = array_keys($conditions);
        for($i = 2; $i < sizeof($array_Conditions); $i++) {
                array_push($dataSourceFilter, array(
                    "columnName" => $array_Conditions[$i],
                    "operator"   => "LIKE_I",
                    "value"      => $conditions[$array_Conditions[$i]]
                ));
        }
        $newRequest                = new DTO\Request\Filter(
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagProdGrpSeg;
        parent::find($newRequest, $response);
    }
    
    public function findProdutoWithSeg($conditions, $request, $response){
        $dataSourceName            = $this->dataSourceName = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_ProdSeg';
        $dataSourceFilter          = array();
        $dataSourceFilter[0] = array(
            "columnName" => 'P_CDFILIAL',
            "operator"   => "=",
            "value"      => $conditions['CDFILIAL']
        ); 
        
        $array_Conditions = array_keys($conditions);
        for($i = 2; $i < sizeof($array_Conditions); $i++) {
                array_push($dataSourceFilter, array(
                    "columnName" => $array_Conditions[$i],
                    "operator"   => "LIKE_I",
                    "value"      => $conditions[$array_Conditions[$i]]
                ));
        }
        $newRequest                = new DTO\Request\Filter(
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagProdGrpSeg;
        parent::find($newRequest, $response);
    }
    
    public function findProdutoAlt($conditions, $request, $response){
        $dataSourceName            = $this->dataSourceName = 'vnd03700_relVendasProdutoPorConsAnaliticoOrd_ProdAlt';
        $dataSourceFilter          = array();
        $dataSourceFilter[0] = array(
            "columnName" => 'P_CDFILIAL',
            "operator"   => "=",
            "value"      => $conditions['CDFILIAL']
        ); 
        $array_Conditions = array_keys($conditions);
        for($i = 2; $i < sizeof($array_Conditions); $i++) {
                array_push($dataSourceFilter, array(
                    "columnName" => $array_Conditions[$i],
                    "operator"   => "LIKE_I",
                    "value"      => $conditions[$array_Conditions[$i]]
                ));
        }
        $newRequest                = new DTO\Request\Filter(
            new FilterCriteria(
                $dataSourceName,
                $dataSourceFilter,
                $request->getFilterCriteria()->getPage()
            ),
            $request->getMethod(),
            $request->getRoutePath(),
            $request->getUserId()
        );
        $this->parameterBagColumns = $this->parameterBagProdGrpSeg;
        parent::find($newRequest, $response);
    }
    
    //Verifica os valores enviados pelo front-end se os campos foram enviados deve-se concatená-los separando-os com underline '_'
    //Se os campos estiverem vazios deve-se considerar como Todos e enviar um campo 'T' para a query
    private function prepareParameters($conditions){
        $FILIAL = $conditions['CDFILIAL'];
        $DTINICIO = $conditions['DTPERIODO'][0];
        $DTFIM   = $conditions['DTPERIODO'][1];
        if(isset($conditions['CDLOJA'])){
            $CDLOJA = join("_", $conditions['CDLOJA']);
            $TCDLOJA = NULL;
            
        } else {
            $CDLOJA = NULL;
            $TCDLOJA = 'T';
        }
        if(isset($conditions['CDCLIENTE'])){
            $CDCLIENTE = join("_", $conditions['CDCLIENTE']);
            $TCDCLIENTE = NULL;
            
        } else {
            $CDCLIENTE = NULL;
            $TCDCLIENTE = 'T';
        }
        if(isset($conditions['CDTIPOCONS'])){
            $CDTIPOCONS = join("_", $conditions['CDTIPOCONS']);
            $TCDTIPOCONS = NULL;
            
        } else {
            $CDTIPOCONS = NULL;
            $TCDTIPOCONS = 'T';
        }
        if(isset($conditions['CDCONSUMIDOR'])){
            $CDCONSUMIDOR = join("_", $conditions['CDCONSUMIDOR']);
            $TCDCONSUMIDOR = NULL;
            
        } else {
            $CDCONSUMIDOR = NULL;
            $TCDCONSUMIDOR = 'T';
        }
        if(isset($conditions['MODALIDADE'])){
            $MODALIDADE = join("_", $conditions['MODALIDADE']);
            $TMODALIDADE = NULL;
            
        } else {
            $MODALIDADE = NULL;
            $TMODALIDADE = 'T';
        }
        if(isset($conditions['CDPRODUTO'])){
            $CDPRODUTO = join("_", $conditions['CDPRODUTO']);
            $TCDPRODUTO = NULL;
            
        } else {
            $CDPRODUTO = NULL;
            $TCDPRODUTO = 'T';
        }
        $parameters = array(
            'TCDCONSUMIDOR' => $TCDCONSUMIDOR,
            'CDCONSUMIDOR'  => $CDCONSUMIDOR,
            'CDCLIENTE'     => $CDCLIENTE,
            'TCDCLIENTE'     => $TCDCLIENTE,
            'CDPRODUTO'     => $CDPRODUTO,
            'CDTIPOCONS'    => $CDTIPOCONS,
            'TCDCLIENTE'    => $TCDCLIENTE,
            'TCDTIPOCONS'   => $TCDTIPOCONS,
            'CDLOJA'        => $CDLOJA,
            'TCDLOJA'       => $TCDLOJA,
            'DTLANCFIN'     => $DTFIM,
            'TCDPRODUTO'    => $TCDPRODUTO,
            'DTLANCINI'     => $DTINICIO,
            'CDFILIAL'      => $FILIAL,
            'MODALIDADE'     => $MODALIDADE,
            'TMODALIDADE'      => $TMODALIDADE
        );
        $dataSourceFilter = RelVendasProdutoConsAnaliticoOrd::createDataSourceFilter($parameters, $conditions);
        return $dataSourceFilter;
    }
    
    private function createDataSourceFilter($parameters, $conditions){
        $dataSourceFilter = array();
        $dataSourceFilter[0] = array(
            "columnName" => 'TCDCONSUMIDOR',
            "operator"   => "=",
            "value"      => $parameters['TCDCONSUMIDOR']
        ); 
        $dataSourceFilter[1] = array(
            "columnName" => 'CDCONSUMIDOR',
            "operator"   => "=",
            "value"      => $parameters['CDCONSUMIDOR']
        ); 
        $dataSourceFilter[2] = array(
            "columnName" => 'CDPRODUTO',
            "operator"   => "=",
            "value"      => $parameters['CDPRODUTO']
        );
        $dataSourceFilter[3] = array(
            "columnName" => 'CDTIPOCONS',
            "operator"   => "=",
            "value"      => $parameters['CDTIPOCONS']
        ); 
        $dataSourceFilter[4] = array(
            "columnName" => 'TCDCLIENTE',
            "operator"   => "=",
            "value"      => $parameters['TCDCLIENTE']
        ); 
        $dataSourceFilter[5] = array(
            "columnName" => 'TCDTIPOCONS',
            "operator"   => "=",
            "value"      => $parameters['TCDTIPOCONS']
        ); 
        $dataSourceFilter[6] = array(
            "columnName" => 'CDLOJA',
            "operator"   => "=",
            "value"      => $parameters['CDLOJA']
        ); 
        $dataSourceFilter[7] = array(
            "columnName" => 'TCDLOJA',
            "operator"   => "=",
            "value"      => $parameters['TCDLOJA']
        ); 
        $dataSourceFilter[8] = array(
            "columnName" => 'DTLANCFIN',
            "operator"   => "=",
            "value"      => $parameters['DTLANCFIN']
        ); 
        $dataSourceFilter[9] = array(
            "columnName" => 'TCDPRODUTO',
            "operator"   => "=",
            "value"      => $parameters['TCDPRODUTO']
        ); 
        $dataSourceFilter[10] = array(
            "columnName" => 'DTLANCINI',
            "operator"   => "=",
            "value"      => $parameters['DTLANCINI']
        ); 
        $dataSourceFilter[11] = array(
            "columnName" => 'CDFILIAL',
            "operator"   => "=",
            "value"      => $parameters['CDFILIAL']
        );
        $dataSourceFilter[12] = array(
            "columnName" => 'MODALIDADE',
            "operator"   => "=",
            "value"      => $parameters['MODALIDADE']
        ); 
        $dataSourceFilter[13] = array(
            "columnName" => 'TMODALIDADE',
            "operator"   => "=",
            "value"      => $parameters['TMODALIDADE']
        ); 
        $dataSourceFilter[14] = array(
            "columnName" => 'CDCLIENTE',
            "operator"   => "=",
            "value"      => $parameters['CDCLIENTE']
        ); 
        $dataSourceFilter[15] = array(
            "columnName" => 'TCDCLIENTE',
            "operator"   => "=",
            "value"      => $parameters['TCDCLIENTE']
        ); 
        return $dataSourceFilter;
    }
    
    private function prepareConsParameters($conditions) {
        $CDFILIAL = $conditions['CDFILIAL'];
        if(isset($conditions['CDTIPOCONS'])){
            $CDTIPOCONS = join("_", $conditions['CDTIPOCONS']);
            $TCDTIPOCONS = NULL;
            
        } else {
            $CDTIPOCONS = NULL;
            $TCDTIPOCONS = 'T';
        }
        
        $parameters = array(
            'CDFILIAL'     => $CDFILIAL,
            'CDTIPOCONS'   => $CDTIPOCONS,
            'TCDTIPOCONS'  => $TCDTIPOCONS
        );
        
        $dataSourceFilter = array();
        
        $dataSourceFilter[0] = array(
            "columnName" => 'CDFILIAL',
            "operator"   => "=",
            "value"      => $parameters['CDFILIAL']
        ); 
        $dataSourceFilter[1] = array(
            "columnName" => 'CDTIPOCONS',
            "operator"   => "=",
            "value"      => $parameters['CDTIPOCONS']
        );
        
        $dataSourceFilter[2] = array(
            "columnName" => 'TCDTIPOCONS',
            "operator"   => "=",
            "value"      => $parameters['TCDTIPOCONS']
        );
        
        
        return $dataSourceFilter;
    }
    
    const QUERY_PRODUTO = "SELECT F.CDFILIAL, F.NMFILIAL, F.CDSEGMER, P.CDGRPRODPDV FROM FILIAL F JOIN PARAVEND P ON ( F.CDFILIAL = P.CDFILIAL (+) ) WHERE ( F.CDFILIAL =:CDFILIAL ) AND F.NRORG =:NRORG AND ROWNUM < 2 ORDER BY F.CDFILIAL";
}